@@ -21,9 +21,8 @@ use strict;
 
 package Math::Permute::List;
 
-sub permute(&@)
+sub permute(&@)        # Generate all permutations of a list
  {my $s = shift;       # Subroutine to call to process each permutation
-
   my $n = scalar(@_);  # Size of array to be permuted
 # return 0 unless $n;  # Empty lists cannot be permuted - removed per Philipp Rumpf
   my $l = 0;           # Item being permuted           
@@ -49,7 +48,9 @@ sub permute(&@)
    };
 
   &$p;
-  
+
+  $p = undef;          # Break memory loop per Philipp Rumpf
+
   my $i = 1; $i *= $_ for 2..$n;
   $i                   # Number of permutations 
  }
@@ -63,12 +64,12 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(permute);
-$VERSION = '1.005';
+$VERSION = '1.006';
 
 =head1 Description
 
-Generate and process all the all the permutations of a list using the
-standard Perl metaphor. 
+Generate and process all the permutations of a list using the standard
+Perl metaphor. 
 
 C<permute()> returns the number of permutations in both scalar and array
 context.
@@ -105,11 +106,17 @@ PhilipRBrenan@appaapps.com
 
 http://www.appaapps.com
 
+=head1 Acknowledgements
+
+With considerable, cogent and unfailing help from Philipp Rumpf for which I am indebted.
+
+http://www.appaapps.com
+
 =head1 See Also
 
 =over
 
-=item L<Math::Cartesian::List>
+=item L<Math::Cartesian::Product>
 
 =item L<Math::Disarrange::List>
 
